@@ -293,8 +293,22 @@ case "$REL" in
         fi
     ;;
     *)
-        echo "You need the NDKv10 or later"
-        exit 1
+        REL2=$(grep -o '^Pkg.Revision.*[0-9]*.*' $ANDROID_NDK/source.properties |cut -d " " -f 3 | cut -d "." -f 1)
+        case "$REL2" in
+            11*)
+                if [ "${HAVE_64}" = 1 ];then
+                    ANDROID_API=android-21
+                    GCCVER=4.9
+                else
+                    ANDROID_API=android-9
+                    GCCVER=4.9
+                fi
+            ;;
+            *)
+            echo "You need the NDKv10 or later"
+            exit 1
+            ;;
+         esac
     ;;
 esac
 
